@@ -1,7 +1,7 @@
 #
 # This file is part of the PyMeasure package.
 #
-# Copyright (c) 2013-2016 PyMeasure Developers
+# Copyright (c) 2013-2017 PyMeasure Developers
 #
 # Permission is hereby granted, free of charge, to any person obtaining a copy
 # of this software and associated documentation files (the "Software"), to deal
@@ -24,7 +24,7 @@
 
 from .instrument import Instrument
 from .mock import Mock
-
+from .resources import list_resources
 
 def discreteTruncate(number, discreteSet):
     """ Truncates the number to the closest element in the positive discrete set.
@@ -50,4 +50,6 @@ from . import parker
 from . import signalrecovery
 from . import srs
 from . import tektronix
-from . import yokogawa
\ No newline at end of file
+from . import thorlabs
+from . import yokogawa
+
